@@ -9,7 +9,6 @@ class GSPSampleKey:
     """Keys for the GSP sample dictionary."""
 
     gsp = "gsp"
-    nominal_capacity_mwp = "gsp_nominal_capacity_mwp"
     effective_capacity_mwp = "gsp_effective_capacity_mwp"
     time_utc = "gsp_time_utc"
     t0_idx = "gsp_t0_idx"
@@ -27,8 +26,7 @@ def convert_gsp_to_numpy_sample(da: xr.DataArray, t0_idx: int | None = None) ->
     """
     sample = {
         GSPSampleKey.gsp: da.values,
-        GSPSampleKey.nominal_capacity_mwp: da.isel(time_utc=0)["nominal_capacity_mwp"].values,
-        GSPSampleKey.effective_capacity_mwp: da.isel(time_utc=0)["effective_capacity_mwp"].values,
+        GSPSampleKey.effective_capacity_mwp: da.effective_capacity_mwp.values[0],
         GSPSampleKey.time_utc: da["time_utc"].values.astype(float),
     }
 
