@@ -1,6 +1,5 @@
 """Convert NWP to NumpySample."""
 
-import pandas as pd
 import xarray as xr
 
 from ocf_data_sampler.numpy_sample.common_types import NumpySample
@@ -28,7 +27,7 @@ def convert_nwp_to_numpy_sample(da: xr.DataArray, t0_idx: int | None = None) ->
         NWPSampleKey.nwp: da.values,
         NWPSampleKey.channel_names: da.channel.values,
         NWPSampleKey.init_time_utc: da.init_time_utc.values.astype(float),
-        NWPSampleKey.step: (da.step.values / pd.Timedelta("1h")).astype(int),
+        NWPSampleKey.step: (da.step.values / 3600).astype(int),
         NWPSampleKey.target_time_utc: da.target_time_utc.values.astype(float),
     }
 
